x for the highest category in y
is plotted, for each subgroup of groups.sjp.gpt(x, y, groups, geom.colors = "Set1", geom.size = 4,
shape.fill.color = "#f0f0f0", shapes = c(15, 16, 17, 18, 21, 22, 23, 24,
25, 7, 8, 9, 10, 12), title = NULL, axisLabels = NULL,
axisTitle.x = NULL, axisTitle.y = NULL, legendTitle = NULL,
legendLabels = NULL, breakTitleAt = 50, breakLabelsAt = 15,
breakLegendTitleAt = 20, breakLegendLabelsAt = 20, axisLimits = NULL,
gridBreaksAt = NULL, showTotal = TRUE, annotateTotal = TRUE,
showP = TRUE, showN = TRUE, hideLegend = FALSE, printPlot = TRUE)y will be printed along the x-axis.y
will be recoded into a binary variable, dichtomized at the highest
category and all remaining categories.varGroup, or a specific color brewer palette code (see 'Note').type argument).
Note that bar and bin widths mostly need smaller values than dot sizes (i.e. if type = "dots").
By default, geom.size = NULL, whicx.title = "my title".
Use NULL to automatically detect variable names that will be used as title
(see set_label) for details). If title =groups labels for the y-axis."" is used, i.e. no title
is printed. If axisTitle.x = NULL, the variable name will be
automatically detected and used as title (see set_label"" is used, i.e. no title
is printed. If axisTitle.y = NULL, variable name will be automatically
detected and used as title (see set_labelgridBreaksAt'th
position a major grid is being printed.TRUE, a total summary line for all aggregated
groups is added.TRUE and showTotal = TRUE,
the total-row in the figure will be highlighted with a slightly
shaded background.TRUE, axis labels for groups will also contain
the results of the chisq.test of x and
y for each groups.TRUE, axis labels for groups will also contain
the total number of cases in each groups.TRUE (default), plots the results as graph. Use FALSE if you don't
want to plot any graphs. In either case, the ggplot-object will be returned as value.plot) as well as the data frame that
was used for setting up the ggplot-object (df).library(sjmisc)
data(efc)
# the proportion of dependency levels in female
# elderly, for each family carer's relationship
# to elderly
sjp.gpt(efc$e42dep, efc$e16sex, efc$e15relat)
# proportion of educational levels in highest
# dependency category of elderly, for different
# care levels
sjp.gpt(efc$c172code, efc$e42dep, efc$n4pstu)Run the code above in your browser using DataLab